import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';
// defines the Colors for Pie Chart different sections
const sectionColors = [
  		'yellow', 'grey', 'blue', 'green', 'red', 'yellow', 'orange', 'brown', 'lime', 'violet'
		  ];
// link or URL of my dataset which is different countries medals
const csvUrl = 'https://gist.githubusercontent.com/EeshwarReddy/278ac25d61b9d72532380c96e9d2c496/raw/b1161e597d1b731afd11829e7bdc61432ecbbcbe/top10countries.csv';
// Function to get or retrive the data from the URL
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');
//text of Format axes
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// These are used to render Pie Chart 
const render = (data, total) => {
  const pieData = pie().value(d=>d.Total)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  // used for generating Arcs of the different sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,220)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Total));
  

  
  // Render legend for the data that we had given
  
  const legends = svg.append("g")
  	.attr("transform", "translate(550,70)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Total));
  legend.append("text")
  	.attr("x", 60)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.Country);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Total/1)));
   // Formats the legend for countries
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Total = +d.Total;
    total += d.Total
  });
	render(data,total);
};
run();